diff --git a/clmctest/monitoring/LineProtocolGenerator.py b/clmctest/monitoring/LineProtocolGenerator.py
index 032d027e2437dbe594ee208a9c3ab9d3c5e5bb76..30e37a4cf315d8e70888fa4531ccfbcd45970486 100644
--- a/clmctest/monitoring/LineProtocolGenerator.py
+++ b/clmctest/monitoring/LineProtocolGenerator.py
@@ -64,14 +64,14 @@ def generate_e2e_delay_report(path_id, source_sfr, target_sfr, endpoint, sf_inst
     return result
 
 
-def generate_network_delay_report(path_id, source_sfr, target_sfr, e2e_delay, time):
+def generate_network_delay_report(path_id, source_sfr, target_sfr, latency, time):
     """
     Generates a platform measurement about the network delay between two specific service routers.
 
     :param path_id: the identifier of the path between the two service routers
     :param source_sfr: the source service router
     :param target_sfr: the target service router
     :param e2e_delay: the e2e network delay for traversing the path between the two service routers
     :param time: the measurement timestamp
     :return: a list of dict-formatted reports to post on influx
     """
@@ -83,7 +83,7 @@ def generate_network_delay_report(path_id, source_sfr, target_sfr, e2e_delay, ti
                    "target": target_sfr
                },
                "fields": {
-                   "delay": e2e_delay
+                   "latency": latency
                },
                "time": _getNSTime(time)
                }]
@@ -114,7 +114,7 @@ def generate_service_delay_report(endpoint, sf_instance, sfr, response_time, req
                "fields": {
                    "response_time": response_time,
                    "request_size": request_size,
-                   "respose_size": response_size
+                   "response_size": response_size
                },
                "time": _getNSTime(time)
                }]
@@ -64,14 +64,14 @@ def generate_e2e_delay_report(path_id, source_sfr, target_sfr, endpoint, sf_inst
     :param source_sfr: the source service router
     :param target_sfr: the target service router
-    :param e2e_delay: the e2e network delay for traversing the path between the two service routers
+    :param latency: the e2e network delay for traversing the path between the two service routers
     :param time: the measurement timestamp
     :return: a list of dict-formatted reports to post on influx